"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var rxjs_1 = require("rxjs");
var shared_1 = require("../../../shared");
var error_1 = require("../../../shared/data/error");
var bit_toolbar_component_1 = require("../../../shared/component/bit-toolbar.component");
var global_constants_1 = require("../../../shared/global.constants");
var fromModels = require("../../models");
var fromRootStore = require("../../../shared/store");
/**
 * Componente que implementa un formulario para insertar, modificar, eliminar y/o consultar un elemento.
 * T: entidad,
 * V: Definicion de la interface del state
 */
var BaseFormComponent = /** @class */ (function () {
    function BaseFormComponent(store, activatedRoute, messageService, factoryCreateAction, fnCreateNewObject) {
        this.store = store;
        this.activatedRoute = activatedRoute;
        this.messageService = messageService;
        this.factoryCreateAction = factoryCreateAction;
        this.fnCreateNewObject = fnCreateNewObject;
        this.breadcrumb = []; // contiene la miga de pan de nuestro componente
        /*tabs properties*/
        this.myTabs = {}; // pestañas definidas en el componente (ver registerTab() e initTabs())
        this.loadedTab = {}; // pestañas con datos cargados (todas se cargan de forma perezosa)
        this.object = this.fnCreateNewObject();
    }
    Object.defineProperty(BaseFormComponent.prototype, "isEditMode", {
        /** Devuelve true si el formulario edita un elemento existente, o false si inserta un nuevo elemento. */
        get: function () {
            return this.formType === global_constants_1.FormType.Update;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseFormComponent.prototype, "isDataChanged", {
        /**
         * Devuelve true si hay algún valor cambiado en la ficha.
         * Puede ser por un campo del formulario (this.myForm.dirty) o por modificaciones en elementos relacionados.
         */
        get: function () {
            return this.myForm && this.myForm.dirty;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseFormComponent.prototype, "isFormValid", {
        /** Devuelve true si el formulario es válido (campos validados automáticamente, elementos relacionados, etc.). */
        get: function () {
            return this.myForm && this.myForm.valid;
        },
        enumerable: true,
        configurable: true
    });
    /** Evalúa si el usuario puede desactivar/cerrar el componente sin perder cambios todavía no guardados. */
    BaseFormComponent.prototype.canDeactivate = function () {
        console.log("canDeactivate called");
        if (this.isDataChanged) {
            //si hay cambios, mostramos la ventana de diálogo
            var p = this.messageService.confirm("Hi ha canvis pendents de desar. Està segur de que vol sortir de la plana i perdre-los?");
            var o = rxjs_1.from(p);
            return o;
        }
        else {
            // si no hay cambios, no la mostramos
            console.log("canDeactivate true");
            return true;
        }
    };
    BaseFormComponent.prototype.unloadWithUnsavedChanges = function ($event) {
        console.log("unloadWithUnsavedChanges called");
        var msg = "Hi ha canvis pendents de desar. Està segur de que vol sortir de la plana i perdre-los?";
        if (this.isDataChanged) {
            ($event || window.event).returnValue = msg;
            return msg;
        }
        return undefined;
    };
    /** el componente toolbar nos comunica que se ha pulsado un botón */
    BaseFormComponent.prototype.onToolbarButtonPressed = function (button) {
        console.log("Button pressed:" + button);
        if (button === bit_toolbar_component_1.BitToolbarComponent.SAVE_BUTTON) {
            this.save();
        }
        else if (button === bit_toolbar_component_1.BitToolbarComponent.DELETE_BUTTON) {
            this.delete();
        }
        else if (button === bit_toolbar_component_1.BitToolbarComponent.PRINT_BUTTON) {
            this.handlePrint();
        }
        else if (button === bit_toolbar_component_1.BitToolbarComponent.HELP_BUTTON) {
            this.help();
        }
        else {
            this.otherAction(button);
        }
    };
    /** Muestra la ayuda asociada a la pantalla. */
    BaseFormComponent.prototype.help = function () { };
    /** el componente toolbar nos comunica que se ha pulsado un botón */
    BaseFormComponent.prototype.handlePrint = function () {
        window.print();
    };
    /** contiene toda la lógica para enviar el formulario al servidor*/
    BaseFormComponent.prototype.save = function () {
        console.log("save called");
        if (!this.myForm.valid) {
            var errores = shared_1.CustomValidators.validateForm(this.myForm);
            this.messageService.sendError(new error_1.Error(null, "Error al formulari", "Error en el formulari", null, null, true, "", errores));
        }
        else {
            if (this.preSave()) {
                console.log("presave");
                if (this.isEditMode) {
                    console.log("update campanya");
                    this.store.dispatch(this.factoryCreateAction(fromModels.GENERIC_TYPE.UPDATE_ITEM, this.object));
                }
                else {
                    console.log("insert campanya");
                    this.store.dispatch(this.factoryCreateAction(fromModels.GENERIC_TYPE.INSERT_ITEM, this.object));
                }
            }
        }
    };
    /** función útil que los componentes pueden extender para hacar algo antes de enviar el formulario al servidor */
    BaseFormComponent.prototype.preSave = function () {
        return true;
    };
    /** contiene la lógica para eliminar el objeto representado en el formulario */
    BaseFormComponent.prototype.delete = function () {
        var p = this.messageService.confirm("Està segur que vol eliminar aquest registre? Aquesta acciò no es podrà desfer?");
        var local = this;
        p.then(function (confirmacion) {
            if (confirmacion) {
                local.store.dispatch(local.factoryCreateAction(fromModels.GENERIC_TYPE.DELETE_ITEM, local.object.id));
            }
        });
    };
    /** Cualquier otra accion que no sea la típica de guardar o eliminar */
    BaseFormComponent.prototype.otherAction = function (action) { };
    /** Limpia el formulario. */
    BaseFormComponent.prototype.cleanForm = function () {
        this.object = this.fnCreateNewObject(); //mejor User.cleanObject();
    };
    /** Cierra el formulario y vuelve a la pantalla anterior. */
    BaseFormComponent.prototype.goBack = function () {
        this.store.dispatch(new fromRootStore.Back());
        //this.router.navigate(["newcampanyas", { query: "true" }]);
    };
    BaseFormComponent.prototype.isPreserveQueryParams = function () {
        return false;
    };
    Object.defineProperty(BaseFormComponent.prototype, "diagnostic", {
        /** Información de debug. */
        get: function () {
            return JSON.stringify(this.object);
        },
        enumerable: true,
        configurable: true
    });
    // Métodos relacionados con pestañas (tabs) //
    /** función para hacer algo si queremos al cambiar de pestaña */
    BaseFormComponent.prototype.changeTab = function (e) { };
    /** Registra una pestaña de visualización de información. */
    BaseFormComponent.prototype.registerTab = function (index, id) {
        this.myTabs[id] = index;
    };
    // inicialización de pestañas (si hay)
    BaseFormComponent.prototype.initTabs = function () {
        this.currentTab = 0;
        this.initialTab = this.activatedRoute.snapshot.params["tab"];
        for (var tab in this.myTabs) {
            var isInitial = this.isInitialTab(tab);
            this.loadedTab[tab] = isInitial;
            if (isInitial) {
                this.currentTab = this.myTabs[tab];
            }
        }
    };
    /** Indica si la pestaña correspondiente es la inicial. */
    BaseFormComponent.prototype.isInitialTab = function (tab) {
        return this.initialTab === tab;
    };
    /** Indica si la pestaña correspondiente está cargada. */
    BaseFormComponent.prototype.isLoadedTab = function (tab) {
        return this.loadedTab[tab];
    };
    BaseFormComponent.propDecorators = {
        unloadWithUnsavedChanges: [{ type: core_1.HostListener, args: ["window:beforeunload",] }]
    };
    return BaseFormComponent;
}());
exports.BaseFormComponent = BaseFormComponent;
//# sourceMappingURL=base-form.component.js.map